@@ -2,7 +2,7 @@ loo1nn <- function(x, y)
 {
 	stopifnot(class(x)=="pdclust" || class(x)=="dist")
 
-	if (class(x)=="dist") {
+	if (any(class(x)=="dist")) {
 		D <- as.matrix(x)
 	} else {
 		D <- as.matrix(x$D)
